@@ -6,7 +6,9 @@ use utf8;
 sub type_str {
     my $self = shift;
     my %type_id2str = reverse %MySQL::BinLog::TYPES;
-    my $type = ($type_id2str{$self->type} =~ s/MYSQL_TYPE_//r);
+    my $type = $type_id2str{$self->type};
+    $type =~ s/MYSQL_TYPE_//;
+    $type;
 }
 
 1;
